@@ -52,7 +52,7 @@ class _ChromosomeMangledSamFile(pysam.Samfile):
                     "Chromosome mangler for %s returned a region not in the file"
                     % (self,)
                 )
-        return pysam.Samfile.parseRegion(
+        return pysam.Samfile.parse_region(
             self,
             contig=contig,
             start=start,
@@ -137,7 +137,7 @@ class _BamDerived:
         return hash(self.__class__.__name__ + self.name)
 
     def load(self):
-        return self.alignment_job, self.index_job
+        return self.alignment_job, self.index_job, self.genome.download_genome
 
     def get_bam(self):
         import multiprocessing
